#!/usr/bin/perl -w
# Based very loosely on Example 10-4 from _Beginning Perl for Bioinformatics_ by Tisdall
#
# Usage: ./get_CDS_simpler.pl < input_filename > output_filename
#
# First, be sure to convert input file to have Unix style line endings, using SubEthaEdit (Format, Line endings, Convert to Unix / Mac OS X) or the following command in the terminal:
# perl -pi -e 's/\r/\n/g' filename

use strict;
use warnings;

# Declare and initialize variables
my @genbank = (  );
my $flag = 0;
my $library = 'library.gb';
my @cds;
my $ncds = 0;
my $protein;
my @names;
my $product;
my $n_unknown = 0;
my $location;

# Read from file indicated at command line.
@genbank = <STDIN>;

# Go through genbank file, line by line, checking for beginning and end of coding sequences.
# Turn on a flag to indicate CDS has started, and turn it off when name is found in /product.

for my $line (@genbank) {

# Coding sequence starts on next line. Find location, set flag, and move on to next line.
  if($line =~ /CDS/) {
    $line =~ /CDS\s*(.*)\n/;
    $location = $1;
    $flag = 1;

# Coding sequence is finished. Get product name.
  }elsif($flag & $line =~ /product/) {
    $line =~ m/product=\"(.*)\n/;
    $product = $1;
    $product =~ s/\"//g;
    $names[$ncds] = $product." at ".$location;

    $protein =~ s/\/translation=//;
    $protein =~ s/\"//g;
    $cds[$ncds] = $protein;

    $ncds++;
    $flag = 0;
    
# First line of coding sequence.
  }elsif($flag & $line =~ /translation/) {
    chomp($line);
    $line =~ s/\s*//;
    $protein = $line;
    
# Continuation of coding sequence. 
  }elsif($flag) {
    chomp($line);
    $line =~ s/\s*//;
    $protein .= $line;
  }
}

# Print all product names and corresponding coding sequences.
for ( my $i = 0; $i < scalar(@cds); $i++) {
    print "> ", $names[$i], "\n", $cds[$i], "\n";
}

exit;
